# gm3dh5

A lightweight interface for GrainMapper3D Results Files. 

[![Python Tests](https://github.com/xnovotech/gm3dh5/actions/workflows/build-tests.yml/badge.svg?branch=main)](https://github.com/xnovotech/gm3dh5/actions/workflows/build-tests.yml)



## Installation

gm3dh5 can be installed using pip by running the command:

```console
pip install gm3dh5
```

Alternative installation methods and further details are available in the [installation guide](https://xnovotech.github.io/gm3dh5/user/installation).

## License

`gm3dh5` is distributed under the terms of the [Apache-2.0](https://spdx.org/licenses/Apache-2.0.html) license.

